set more off
cap log close

global sourcedata C:\Users\Tano\Documents\UCD\RA\Giovanni_MigrationConference2015
cd C:\Users\Tano\Dropbox\Giovanni_MigrationConference2015

log using logfiles\count_czone_census19702010.txt, text replace

disp "DateTime: $S_DATE $S_TIME"

/* *******************************************************************
 Based on the dofile by Borjas obtained from Giovanni Peri on 
 1/1/2015.

 Calculates fte's, counts of workers, and population counts, by education 
 (4 groups), experience (2 groups) by czone.
 Delete group quarters, keep both working age male and female in lf with 
 positive weeks, hours, earnings, and NOT delete school enrolled.
 Keep only 48 contigous states. Collapse at CZ level using programs 
 by David Dorn.

 Redefine weight as perwt adjusted by hours worked (same as Borjas) 
 multiplied by CZ factor (see Dorn's documentation).
 
 Created by Gaetano Basso (gbasso@ucdavis.edu) on 1/3/2015. 
******************************************************************* */


*** Correct Dorn 1970 CtyGrp-to-CZone x-walk ***
use Dorn_CZ\cw_ctygrp1970_czone.dta, clear
qui des
local j = `r(N)'+1
set obs `j'
replace ctygrp1970 = 505 if ctygrp1970==.&czone==.&afactor==.
replace czone = 20800 if ctygrp1970==505
replace afactor = 1 if ctygrp1970==505
qui des
local j = `r(N)'+1
set obs `j'
replace ctygrp1970 = 506 if ctygrp1970==.&czone==.&afactor==.
replace czone = 20800 if ctygrp1970==506
replace afactor = 1 if ctygrp1970==506
* Drop Alaska and Hawaii CZone
drop if (czone>=34101&czone<=34115)|(czone>=34701&czone<=34703)|czone==35600
tempfile cw_ctygrp1970_czone_corrected
save `cw_ctygrp1970_czone_corrected'


*** Census 1970 (metro fm1) ***
use ${sourcedata}/rawdata/ipums_1970_metrofm1.dta, clear

drop if gq==0 | gq==3 | gq==4 
keep if age>=18 & age<=64
*keep if sex==1
gen school = .
replace school=higraded - (int(higraded/10))*10
*drop if school==2

*keep if datanum==3 // Borjas uses only 1970 metro fm1

* Rescale perwt due to 2% sample
replace perwt=perwt/2

generate byte imm=(citizen==2 | citizen==3)
drop citizen

generate weeks=8.0*(wkswork2==1) + 20.8*(wkswork2==2) + 33.1*(wkswork2==3) ///
	+ 42.4*(wkswork2==4) + 48.3*(wkswork2==5) + 51.9*(wkswork2==6)
generate hours=8.7*(hrswork2==1) + 20.9*(hrswork2==2) + 31.1*(hrswork2==3) ///
	+ 36.5*(hrswork2==4) + 40*(hrswork2==5) + 45.3*(hrswork2==6) ///
	+ 51.8*(hrswork2==7) + 68.1*(hrswork2==8) 


generate byte edcode=1*(educd<=50) + 2*(educd>=60 & educd<=64) ///
	+ 3*(educd>=65 & educd<=90) + 4*(educd>=100)

generate exper=age-17 if edcode==1
replace exper=age-19 if edcode==2
replace exper=age-21 if edcode==3
replace exper=age-23 if edcode==4
keep if exper>=1 & exper<=41

generate expcode=1*(exper>=1 & exper<=20) + 2*(exper>=21 & exper<=41)

* Merge with CZ info (obtained by Dorn's website on 1/3/2015,
* "http://www.ddorn.net/data.htm") and create new weights
rename cntygp97 ctygrp1970
joinby ctygrp1970 using `cw_ctygrp1970_czone_corrected'


generate weight=perwt*weeks*hours/2000*afactor
generate czweight=perwt*afactor

rename statefip state
generate pimmig=imm*czweight
generate pnative=(1-imm)*czweight
generate nimmig=imm*czweight*(weeks>0)
generate nnative=(1-imm)*czweight*(weeks>0)
generate immiglf=imm*weight
generate nativelf=(1-imm)*weight

compress
save ${sourcedata}/rawdata/junk70fm1.dta, replace


*** Census 1970 (metro fm2) ***
use ${sourcedata}/rawdata/ipums_1970_metrofm2.dta, clear

drop if gq==0 | gq==3 | gq==4 
keep if age>=18 & age<=64
*keep if sex==1
*drop if school==2

*keep if datanum==3 // Borjas uses only 1970 metro fm1

* Rescale perwt due to 2% sample
replace perwt=perwt/2

generate byte imm=(bpld>=15000)
replace imm=0 if bpld==90011 | bpld==90021
*keep if imm==0


generate weeks=8.0*(wkswork2==1) + 20.8*(wkswork2==2) + 33.1*(wkswork2==3) ///
	+ 42.4*(wkswork2==4) + 48.3*(wkswork2==5) + 51.9*(wkswork2==6)
generate hours=8.7*(hrswork2==1) + 20.9*(hrswork2==2) + 31.1*(hrswork2==3) ///
	+ 36.5*(hrswork2==4) + 40*(hrswork2==5) + 45.3*(hrswork2==6) ///
	+ 51.8*(hrswork2==7) + 68.1*(hrswork2==8) 


generate byte edcode=1*(educd<=50) + 2*(educd>=60 & educd<=64) ///
	+ 3*(educd>=65 & educd<=90) + 4*(educd>=100)

generate exper=age-17 if edcode==1
replace exper=age-19 if edcode==2
replace exper=age-21 if edcode==3
replace exper=age-23 if edcode==4
keep if exper>=1 & exper<=41

generate expcode=1*(exper>=1 & exper<=20) + 2*(exper>=21 & exper<=41)

* Merge with CZ info (obtained by Dorn's website on 1/3/2015,
* "http://www.ddorn.net/data.htm") and create new weights
rename cntygp97 ctygrp1970
joinby ctygrp1970 using `cw_ctygrp1970_czone_corrected'

generate weight=perwt*weeks*hours/2000*afactor
generate czweight=perwt*afactor

rename statefip state
generate pimmig=imm*czweight
generate pnative=(1-imm)*czweight
generate nimmig=imm*czweight*(weeks>0)
generate nnative=(1-imm)*czweight*(weeks>0)
generate immiglf=imm*weight
generate nativelf=(1-imm)*weight

append using ${sourcedata}/rawdata/junk70fm1

collapse (sum) pimmig pnative nimmig nnative immiglf nativelf ///
	(count) size=czweight, ///
    by(czone edcode expcode)

/*
** Generate indicator for missing CZ **
preserve
use `cw_ctygrp1970_czone_corrected', clear
keep czone
duplicates drop
tempfile checkczone
save `checkczone'
restore
merge m:1 czone using `checkczone'
gen no1970cz = _m==2
preserve
keep if no1970cz==1
keep czone no1970cz
cap duplicates drop
tempfile no1970cz
save `no1970cz'
restore
drop _m
expand 2 if no1970cz==1
bys czone: replace expcode = 1 if no1970cz==1&_n==1
bys czone: replace expcode = 2 if no1970cz==1&_n==2
expand 4 if no1970cz==1
bys czone expcode: replace edcode = 1 if no1970cz==1&_n==1
bys czone expcode: replace edcode = 2 if no1970cz==1&_n==2
bys czone expcode: replace edcode = 3 if no1970cz==1&_n==3
bys czone expcode: replace edcode = 4 if no1970cz==1&_n==4
*/

generate survey=1970
sort survey czone edcode expcode

compress
save ${sourcedata}/rawdata/junk70.dta, replace


*** Census 1980 ***
use ${sourcedata}/rawdata/ipums_1980.dta, clear

drop if gq==0 | gq==3 | gq==4 
keep if age>=18 & age<=64
*keep if sex==1
*drop if school==2

generate byte imm=(citizen==2 | citizen==3)
*keep if imm==0

summ wkswork1 uhrswork incwage
generate weeks=wkswork1
generate hours=uhrswork

generate byte edcode=1*(educd<=50) + 2*(educd>=60 & educd<=64) ///
	+ 3*(educd>=65 & educd<=90) + 4*(educd>=100)

generate exper=age-17 if edcode==1
replace exper=age-19 if edcode==2
replace exper=age-21 if edcode==3
replace exper=age-23 if edcode==4
keep if exper>=1 & exper<=41

generate expcode=1*(exper>=1 & exper<=20) + 2*(exper>=21 & exper<=41)
	
* Merge with CZ info (obtained by Dorn's website on 1/3/2015,
* "http://www.ddorn.net/data.htm") and create new weights
rename cntygp98 ctygrp1980
replace ctygrp1980 = statefip*1000+ctygrp1980
*drop if ctygrp1980==0
joinby ctygrp1980 using Dorn_CZ\cw_ctygrp1980_czone.dta

generate weight=perwt*weeks*hours/2000*afactor
generate czweight=perwt*afactor

rename statefip state
generate pimmig=imm*czweight
generate pnative=(1-imm)*czweight
generate nimmig=imm*czweight*(weeks>0)
generate nnative=(1-imm)*czweight*(weeks>0)
generate immiglf=imm*weight
generate nativelf=(1-imm)*weight


collapse (sum) pimmig pnative nimmig nnative immiglf nativelf ///
	(count) size=czweight, ///
    by(czone edcode expcode)

/*
* Merge with no1970cz to create indicator
merge m:1 czone using `no1970cz', nogen
replace no1970cz=0 if no1970cz==.
*/

generate survey=1980
sort survey czone edcode expcode

compress
save ${sourcedata}/rawdata/junk80.dta, replace

*** Census 1990 ***
use ${sourcedata}/rawdata/ipums_1990.dta, clear

drop if gq==0 | gq==3 | gq==4 
keep if age>=18 & age<=64
*keep if sex==1
*drop if school==2

generate byte imm=(citizen==2 | citizen==3)
*keep if imm==0

summ wkswork1 uhrswork incwage
generate weeks=wkswork1
generate hours=uhrswork

generate byte edcode=1*(educd<=50) + 2*(educd>=60 & educd<=64) ///
	+ 3*(educd>=65 & educd<=90) + 4*(educd>=100)

generate exper=age-17 if edcode==1
replace exper=age-19 if edcode==2
replace exper=age-21 if edcode==3
replace exper=age-23 if edcode==4
keep if exper>=1 & exper<=41

generate expcode=1*(exper>=1 & exper<=20) + 2*(exper>=21 & exper<=41)

* Merge with CZ info (obtained by Dorn's website on 1/3/2015,
* "http://www.ddorn.net/data.htm") and create new weights
rename puma puma1990
replace puma1990 = statefip*10000+puma1990
*drop if puma1990==0
joinby puma1990 using Dorn_CZ\cw_puma1990_czone.dta

generate weight=perwt*weeks*hours/2000*afactor
generate czweight=perwt*afactor

rename statefip state
generate pimmig=imm*czweight
generate pnative=(1-imm)*czweight
generate nimmig=imm*czweight*(weeks>0)
generate nnative=(1-imm)*czweight*(weeks>0)
generate immiglf=imm*weight
generate nativelf=(1-imm)*weight


collapse (sum) pimmig pnative nimmig nnative immiglf nativelf ///
	(count) size=czweight, ///
    by(czone edcode expcode)

/*
* Merge with no1970cz to create indicator
merge m:1 czone using `no1970cz', nogen
replace no1970cz=0 if no1970cz==.
*/

generate survey=1990
sort survey czone edcode expcode

compress
save ${sourcedata}/rawdata/junk90.dta, replace


*** Census 2000 ***
use ${sourcedata}/rawdata/ipums_2000.dta, clear

drop if gq==0 | gq==3 | gq==4 
keep if age>=18 & age<=64
*keep if sex==1
*drop if school==2

generate byte imm=(citizen==2 | citizen==3)
*keep if imm==0

generate byte edcode=1*(educd<=50) + 2*(educd>=60 & educd<=64) ///
	+ 3*(educd>=65 & educd<=90) + 4*(educd>=100)

generate exper=age-17 if edcode==1
replace exper=age-19 if edcode==2
replace exper=age-21 if edcode==3
replace exper=age-23 if edcode==4
keep if exper>=1 & exper<=41

generate expcode=1*(exper>=1 & exper<=20) + 2*(exper>=21 & exper<=41)

generate weeks=wkswork1
generate hours=uhrswork

* Merge with CZ info (obtained by Dorn's website on 1/3/2015,
* "http://www.ddorn.net/data.htm") and create new weights
rename puma puma2000
replace puma2000 = statefip*10000+puma2000
*cap drop if puma2000==0
joinby puma2000 using Dorn_CZ/cw_puma2000_czone.dta

generate weight=perwt*weeks*hours/2000*afactor
generate czweight=perwt*afactor

rename statefip state
generate pimmig=imm*czweight
generate pnative=(1-imm)*czweight
generate nimmig=imm*czweight*(weeks>0)
generate nnative=(1-imm)*czweight*(weeks>0)
generate immiglf=imm*weight
generate nativelf=(1-imm)*weight


collapse (sum) pimmig pnative nimmig nnative immiglf nativelf /// 
	(count) size=czweight, /// 
    by(czone edcode expcode)

/*
* Merge with no1970cz to create indicator
merge m:1 czone using `no1970cz', nogen
replace no1970cz=0 if no1970cz==.
*/

generate survey=2000
sort survey czone edcode expcode

compress
save ${sourcedata}/rawdata/junk00.dta, replace


*** Census ACS 5yr 2008-2012 ***
use ${sourcedata}/rawdata/ipums_2010.dta, clear

drop if gq==0 | gq==3 | gq==4 
keep if age>=18 & age<=64
*keep if sex==1
*drop if school==2

generate byte imm=(citizen==2 | citizen==3)
*keep if imm==0

generate byte edcode=1*(educd<=50) + 2*(educd>=60 & educd<=64) ///
	+ 3*(educd>=65 & educd<=90) + 4*(educd>=100)

generate exper=age-17 if edcode==1
replace exper=age-19 if edcode==2
replace exper=age-21 if edcode==3
replace exper=age-23 if edcode==4
keep if exper>=1 & exper<=41

generate expcode=1*(exper>=1 & exper<=20) + 2*(exper>=21 & exper<=41)

generate weeks=7.4*(wkswork2==1) + 21.3*(wkswork2==2) + 33.1*(wkswork2==3) ///
	+ 42.4*(wkswork2==4) + 48.2*(wkswork2==5) + 51.9*(wkswork2==6) 
generate hours=uhrswork

* Merge with CZ info (obtained by Dorn's website on 1/3/2015,
* "http://www.ddorn.net/data.htm") and create new weights
rename puma puma2000
replace puma2000 = statefip*10000+puma2000
*cap drop if puma2000==0
joinby puma2000 using Dorn_CZ/cw_puma2000_czone.dta

generate weight=perwt*weeks*hours/2000*afactor
generate czweight=perwt*afactor

rename statefip state
generate pimmig=imm*czweight
generate pnative=(1-imm)*czweight
generate nimmig=imm*czweight*(weeks>0)
generate nnative=(1-imm)*czweight*(weeks>0)
generate immiglf=imm*weight
generate nativelf=(1-imm)*weight


collapse (sum) pimmig pnative nimmig nnative immiglf nativelf /// 
	(count) size=czweight, /// 
    by(czone edcode expcode)

/*
* Merge with no1970cz to create indicator
merge m:1 czone using `no1970cz', nogen
replace no1970cz=0 if no1970cz==.
*/

generate survey=2010
sort survey czone edcode expcode

compress
save ${sourcedata}/rawdata/junk10.dta, replace

*** Put data together ***
use ${sourcedata}/rawdata/junk70.dta
append using ${sourcedata}/rawdata/junk80.dta
append using ${sourcedata}/rawdata/junk90.dta
append using ${sourcedata}/rawdata/junk00.dta
append using ${sourcedata}/rawdata/junk10.dta

sort survey czone edcode expcode

* Drop Hawaii and Alaska CZ in 1970
drop if (czone>=34101&czone<=34115)|(czone>=34701&czone<=34703)|czone==35600
cap drop no1970cz

compress
saveold data/count_czone_byEduExp.dta, replace

log close

*** Clean folder ***
cd ${sourcedata}/rawdata
shell erase junk?0.dta
shell erase junk?0.dta
shell erase junk70fm1.dta

