set more off
cap log close

cd C:\Users\Tano\Dropbox\Giovanni_MigrationConference2015
global sourcedata C:\Users\Tano\Documents\UCD\RA\Giovanni_MigrationConference2015

log using logfiles\dataset_SectorBartik_EnclaveBartik_CZ.txt, text replace

disp "DateTime: $S_DATE $S_TIME"

/* *******************************************************************
 Generate CZ-level Sector Bartik for wage and employment and Enclave 
 Bartik for immigrants. To be merged to CZ aggregated and cell (exp-edu) 
 datasets. For each CZ in 1970-2010.
 
 Structure of dofile:
 1. Correct Dorn CZ crosswalk 
 2. Import and clean employment and wages by decade (and empl share in 1970)
 3. Import and clean immigrant data by czone and decade
 4. Put data together and save (and erase temp file)
 
 Created on 1/12/2015 by Gaetano Basso (gbasso@ucdavis.edu). Update on 4/21/2015
******************************************************************* */


***************************************************
*** 1. Correct Dorn 1970 CtyGrp-to-CZone x-walk ***
***************************************************
use Dorn_CZ\cw_ctygrp1970_czone.dta, clear
qui des
local j = `r(N)'+1
set obs `j'
replace ctygrp1970 = 505 if ctygrp1970==.&czone==.&afactor==.
replace czone = 20800 if ctygrp1970==505
replace afactor = 1 if ctygrp1970==505
qui des
local j = `r(N)'+1
set obs `j'
replace ctygrp1970 = 506 if ctygrp1970==.&czone==.&afactor==.
replace czone = 20800 if ctygrp1970==506
replace afactor = 1 if ctygrp1970==506
* Drop Alaska and Hawaii CZone
drop if (czone>=34101&czone<=34115)|(czone>=34701&czone<=34703)|czone==35600
tempfile cw_ctygrp1970_czone_corrected
save `cw_ctygrp1970_czone_corrected'

** Useful dataset that list all CZ
gen one = 1
collapse one, by(czone)
tempfile allczone
save `allczone'


******************************************************
*** 2. Import IPUMS employment and wages by decade ***
*** (also create 1970 empl share by czone) 		   ***
******************************************************

*** Employment Census 1970 (metro fm1) ***
use ${sourcedata}/rawdata/ipums_1970_metrofm1.dta, clear

drop if gq==0 | gq==3 | gq==4 
* Alaska and Hawaii dropped when merging with CZ xwalk
keep if age>=18 & age<=64
gen school = .
replace school=higraded - (int(higraded/10))*10

* Rescale perwt due to 2% sample
replace perwt=perwt/2

generate byte imm=(citizen==2 | citizen==3)
drop citizen

generate weeks=8.0*(wkswork2==1) + 20.8*(wkswork2==2) + 33.1*(wkswork2==3) ///
	+ 42.4*(wkswork2==4) + 48.3*(wkswork2==5) + 51.9*(wkswork2==6)

generate byte edcode=1*(educd<=50) + 2*(educd>=60 & educd<=64) ///
	+ 3*(educd>=65 & educd<=90) + 4*(educd>=100)

generate exper=age-17 if edcode==1
replace exper=age-19 if edcode==2
replace exper=age-21 if edcode==3
replace exper=age-23 if edcode==4
keep if exper>=1 & exper<=41

* Merge with CZ info (obtained by Dorn's website on 1/3/2015,
* "http://www.ddorn.net/data.htm") and create new weights
rename cntygp97 ctygrp1970
joinby ctygrp1970 using `cw_ctygrp1970_czone_corrected'

compress
tempfile empljunk70fm1
save `empljunk70fm1', replace

*** Employment Census 1970 (metro fm2) ***
use ${sourcedata}/rawdata/ipums_1970_metrofm2.dta, clear

drop if gq==0 | gq==3 | gq==4 
* Alaska and Hawaii dropped when merging with CZ xwalk
keep if age>=18 & age<=64

* Rescale perwt due to 2% sample
replace perwt=perwt/2

generate byte imm=(bpld>=15000)
replace imm=0 if bpld==90011 | bpld==90021

generate weeks=8.0*(wkswork2==1) + 20.8*(wkswork2==2) + 33.1*(wkswork2==3) ///
	+ 42.4*(wkswork2==4) + 48.3*(wkswork2==5) + 51.9*(wkswork2==6)

generate byte edcode=1*(educd<=50) + 2*(educd>=60 & educd<=64) ///
	+ 3*(educd>=65 & educd<=90) + 4*(educd>=100)

generate exper=age-17 if edcode==1
replace exper=age-19 if edcode==2
replace exper=age-21 if edcode==3
replace exper=age-23 if edcode==4
keep if exper>=1 & exper<=41

* Merge with CZ info (obtained by Dorn's website on 1/3/2015,
* "http://www.ddorn.net/data.htm") and create new weights
rename cntygp97 ctygrp1970
joinby ctygrp1970 using `cw_ctygrp1970_czone_corrected'

append using `empljunk70fm1'

** Correct industry 1990 
run dofiles/ind1990aggregation.do

generate czweight=perwt*afactor

rename statefip state
generate nimmig=imm*czweight*(weeks>0)
generate nnative=(1-imm)*czweight*(weeks>0)

** Temporary dataset that list all CZ and industries
preserve 
gen one = 1
collapse one, by(ind1990)
joinby one using `allczone'
tempfile ind1990
save `ind1990'
restore

*** 1970 industry share ***
preserve 
collapse (sum) nimmig nnative (count) size=czweight, ///
    by(czone ind1990)
gen x = nimmig+nnative
bys czone: egen empl = total(x)
bys czone ind1990: gen shempl1970 = x/empl
drop x
merge 1:1 czone ind1990 using `ind1990', gen(m_allind)
foreach v of varlist empl shempl1970 nnative nimmig {
replace `v'=0 if m_allind==2
}
drop m_allind
sort ind1990

keep czone ind1990 shempl1970
compress
save ${sourcedata}/rawdata/emplsharejunk70.dta, replace
restore

collapse (sum) nimmig nnative (count) size=czweight, ///
    by(ind1990)

generate survey=1970

gen x = nimmig+nnative
bys ind1990 survey: egen empl = total(x)
replace empl = log(empl)
rename empl lempl
drop x

merge 1:m ind1990 using ${sourcedata}/rawdata/emplsharejunk70.dta, gen(m1970_shareempl1970)
tab m1970
drop m1970

compress
save ${sourcedata}/rawdata/empljunk70.dta, replace


*** Wages Census 1970 (metro fm1) ***
use ${sourcedata}/rawdata/ipums_1970_metrofm1.dta, clear

drop if gq==0 | gq==3 | gq==4 
drop if statefip==2|statefip==15
keep if age>=18 & age<=64
keep if wkswork2>0 
gen school = .
replace school=higraded - (int(higraded/10))*10
drop if school==2
keep if classwkrd>=22 & classwkrd<=28

* Rescale perwt due to 2% sample
replace perwt=perwt/2

generate byte imm=(citizen==2 | citizen==3)
drop citizen

generate weeks=8.0*(wkswork2==1) + 20.8*(wkswork2==2) + 33.1*(wkswork2==3) ///
	+ 42.4*(wkswork2==4) + 48.3*(wkswork2==5) + 51.9*(wkswork2==6)
generate hours=8.7*(hrswork2==1) + 20.9*(hrswork2==2) + 31.1*(hrswork2==3) ///
	+ 36.5*(hrswork2==4) + 40*(hrswork2==5) + 45.3*(hrswork2==6) ///
	+ 51.8*(hrswork2==7) + 68.1*(hrswork2==8) 
drop if weeks==0
drop if hours==0

replace incwage=50000*1.5 if incwage==50000
keep if incwage>0
replace incwage=incwage*(166.6/36.7)
generate lweekly=log(incwage/weeks)
generate lannual=log(incwage)
generate lwage=log(incwage/(weeks*hours))

generate byte edcode=1*(educd<=50) + 2*(educd>=60 & educd<=64) ///
	+ 3*(educd>=65 & educd<=90) + 4*(educd>=100)

generate exper=age-17 if edcode==1
replace exper=age-19 if edcode==2
replace exper=age-21 if edcode==3
replace exper=age-23 if edcode==4
keep if exper>=1 & exper<=41

generate weight=perwt*(weeks/52)
generate czweight=perwt

tempfile wagesfm1
save `wagesfm1'


*** Wages Census 1970 (metro fm2) ***
use ${sourcedata}/rawdata/ipums_1970_metrofm2.dta, clear

drop if gq==0 | gq==3 | gq==4 
drop if statefip==2|statefip==15
keep if age>=18 & age<=64
keep if wkswork2>0 
drop if school==2
keep if classwkrd>=22 & classwkrd<=28

* Rescale perwt due to 2% sample
replace perwt=perwt/2

generate byte imm=(bpld>=15000)
replace imm=0 if bpld==90011 | bpld==90021

generate weeks=8.0*(wkswork2==1) + 20.8*(wkswork2==2) + 33.1*(wkswork2==3) ///
	+ 42.4*(wkswork2==4) + 48.3*(wkswork2==5) + 51.9*(wkswork2==6)
generate hours=8.7*(hrswork2==1) + 20.9*(hrswork2==2) + 31.1*(hrswork2==3) ///
	+ 36.5*(hrswork2==4) + 40*(hrswork2==5) + 45.3*(hrswork2==6) ///
	+ 51.8*(hrswork2==7) + 68.1*(hrswork2==8) 
drop if weeks==0
drop if hours==0

replace incwage=50000*1.5 if incwage==50000
keep if incwage>0
replace incwage=incwage*(166.6/36.7)
generate lweekly=log(incwage/weeks)
generate lannual=log(incwage)
generate lwage=log(incwage/(weeks*hours))

generate byte edcode=1*(educd<=50) + 2*(educd>=60 & educd<=64) ///
	+ 3*(educd>=65 & educd<=90) + 4*(educd>=100)

generate exper=age-17 if edcode==1
replace exper=age-19 if edcode==2
replace exper=age-21 if edcode==3
replace exper=age-23 if edcode==4
keep if exper>=1 & exper<=41

generate weight=perwt*(weeks/52)
generate czweight=perwt

append using `wagesfm1'

** Correct industry 1990 
run dofiles/ind1990aggregation.do

collapse (mean) lweekly (count) sizew=czweight (rawsum) sumweight=weight /// 
	[aw=weight], by(ind1990)

generate survey=1970
sort survey ind1990

merge 1:m ind1990 using ${sourcedata}/rawdata/emplsharejunk70.dta, gen(m1970_shareempl1970)
tab m1970

compress
save ${sourcedata}/rawdata/wagesjunk70.dta, replace




*** Employment Census 1980 ***
use ${sourcedata}/rawdata/ipums_1980.dta, clear

drop if gq==0 | gq==3 | gq==4 
drop if statefip==2|statefip==15
keep if age>=18 & age<=64

generate byte imm=(citizen==2 | citizen==3)

summ wkswork1 uhrswork incwage
generate weeks=wkswork1
generate hours=uhrswork

generate byte edcode=1*(educd<=50) + 2*(educd>=60 & educd<=64) ///
	+ 3*(educd>=65 & educd<=90) + 4*(educd>=100)

generate exper=age-17 if edcode==1
replace exper=age-19 if edcode==2
replace exper=age-21 if edcode==3
replace exper=age-23 if edcode==4
keep if exper>=1 & exper<=41

generate expcode=1*(exper>=1 & exper<=20) + 2*(exper>=21 & exper<=41)

generate weight=perwt*weeks*hours/2000
generate czweight=perwt

rename statefip state
generate nimmig=imm*czweight*(weeks>0)
generate nnative=(1-imm)*czweight*(weeks>0)

** Correct industry 1990 
run dofiles/ind1990aggregation.do

collapse (sum) nimmig nnative (count) size=czweight, ///
    by(ind1990)

generate survey=1980
gen x = nimmig+nnative
bys ind1990 survey: egen empl = total(x)
replace empl = log(empl)
rename empl lempl
drop x
sort survey ind1990

merge 1:m ind1990 using ${sourcedata}/rawdata/emplsharejunk70.dta, gen(m1980_shareempl1970)
tab m1980

compress
save ${sourcedata}/rawdata/empljunk80.dta, replace

*** Wages Census 1980 ***
use ${sourcedata}/rawdata/ipums_1980.dta, clear

drop if gq==0 | gq==3 | gq==4 
drop if statefip==2|statefip==15
keep if age>=18 & age<=64
keep if wkswork1>0
drop if school==2
keep if classwkrd>=22 & classwkrd<=28

generate byte imm=(citizen==2 | citizen==3)

summ wkswork1 uhrswork incwage
generate weeks=wkswork1
drop if weeks==0
generate hours=uhrswork
drop if hours==0

replace incwage=75000*1.5 if incwage==75000
keep if incwage>0
replace incwage=incwage*(166.6/72.6)
generate lweekly=log(incwage/weeks)
generate lannual=log(incwage)
generate lwage=log(incwage/(weeks*hours))

generate byte edcode=1*(educd<=50) + 2*(educd>=60 & educd<=64) ///
	+ 3*(educd>=65 & educd<=90) + 4*(educd>=100)

generate exper=age-17 if edcode==1
replace exper=age-19 if edcode==2
replace exper=age-21 if edcode==3
replace exper=age-23 if edcode==4
keep if exper>=1 & exper<=41

generate expcode=1*(exper>=1 & exper<=20) + 2*(exper>=21 & exper<=41)
	
generate weight=perwt*weeks/52
generate czweight=perwt

** Correct industry 1990 
run dofiles/ind1990aggregation.do

collapse (mean) lweekly (count) sizew=czweight (rawsum) sumweight=weight ///
	[aw=weight], by(ind1990)

generate survey=1980
sort survey ind1990

merge 1:m ind1990 using ${sourcedata}/rawdata/emplsharejunk70.dta, gen(m1980_shareempl1970)
tab m1980

compress
save ${sourcedata}/rawdata/wagesjunk80.dta, replace



*** Employment Census 1990 ***
use ${sourcedata}/rawdata/ipums_1990.dta, clear

drop if gq==0 | gq==3 | gq==4 
drop if statefip==2|statefip==15
keep if age>=18 & age<=64

generate byte imm=(citizen==2 | citizen==3)

summ wkswork1 uhrswork incwage
generate weeks=wkswork1
generate hours=uhrswork

generate byte edcode=1*(educd<=50) + 2*(educd>=60 & educd<=64) ///
	+ 3*(educd>=65 & educd<=90) + 4*(educd>=100)

generate exper=age-17 if edcode==1
replace exper=age-19 if edcode==2
replace exper=age-21 if edcode==3
replace exper=age-23 if edcode==4
keep if exper>=1 & exper<=41

generate czweight=perwt

rename statefip state
generate nimmig=imm*czweight*(weeks>0)
generate nnative=(1-imm)*czweight*(weeks>0)

** Correct industry 1990 
run dofiles/ind1990aggregation.do

collapse (sum) nimmig nnative (count) size=czweight, ///
    by(ind1990)

generate survey=1990
gen x = nimmig+nnative
bys ind1990 survey: egen empl = total(x)
replace empl = log(empl)
rename empl lempl
drop x
sort survey ind1990

merge 1:m ind1990 using ${sourcedata}/rawdata/emplsharejunk70.dta, gen(m1990_shareempl1970)
tab m1990

compress
save ${sourcedata}/rawdata/empljunk90.dta, replace


*** Wages Census 1990 ***
use ${sourcedata}/rawdata/ipums_1990.dta, clear

drop if gq==0 | gq==3 | gq==4 
drop if statefip==2|statefip==15
keep if age>=18 & age<=64
keep if wkswork1>0
drop if school==2
keep if classwkrd>=22 & classwkrd<=28


generate byte imm=(citizen==2 | citizen==3)

summ wkswork1 uhrswork incwage
generate weeks=wkswork1
drop if weeks==0
generate hours=uhrswork
drop if hours==0

keep if incwage>0
replace incwage=incwage*(166.6/124.0)
generate lweekly=log(incwage/weeks)
generate lannual=log(incwage)
generate lwage=log(incwage/(weeks*hours))


generate byte edcode=1*(educd<=50) + 2*(educd>=60 & educd<=64) ///
	+ 3*(educd>=65 & educd<=90) + 4*(educd>=100)

generate exper=age-17 if edcode==1
replace exper=age-19 if edcode==2
replace exper=age-21 if edcode==3
replace exper=age-23 if edcode==4
keep if exper>=1 & exper<=41

generate weight=perwt*weeks/52
generate czweight=perwt

** Correct industry 1990 
run dofiles/ind1990aggregation.do

collapse (mean) lweekly (count) sizew=czweight (rawsum) sumweight=weight ///
	[aw=weight], by(ind1990)

generate survey=1990
sort survey ind1990

merge 1:m ind1990 using ${sourcedata}/rawdata/emplsharejunk70.dta, gen(m1990_shareempl1970)
tab m1990

compress
save ${sourcedata}/rawdata/wagesjunk90.dta, replace



*** Empl Census 2000 ***
use ${sourcedata}/rawdata/ipums_2000.dta, clear

drop if gq==0 | gq==3 | gq==4 
drop if statefip==2|statefip==15
keep if age>=18 & age<=64

generate byte imm=(citizen==2 | citizen==3)

generate byte edcode=1*(educd<=50) + 2*(educd>=60 & educd<=64) ///
	+ 3*(educd>=65 & educd<=90) + 4*(educd>=100)

generate exper=age-17 if edcode==1
replace exper=age-19 if edcode==2
replace exper=age-21 if edcode==3
replace exper=age-23 if edcode==4
keep if exper>=1 & exper<=41

generate weeks=wkswork1

generate czweight=perwt

rename statefip state
generate nimmig=imm*czweight*(weeks>0)
generate nnative=(1-imm)*czweight*(weeks>0)

** Correct industry 1990 
run dofiles/ind1990aggregation.do

collapse (sum) nimmig nnative (count) size=czweight, /// 
    by(ind1990)

generate survey=2000
gen x = nimmig+nnative
bys ind1990 survey: egen empl = total(x)
replace empl = log(empl)
rename empl lempl
drop x
sort survey ind1990

merge 1:m ind1990 using ${sourcedata}/rawdata/emplsharejunk70.dta, gen(m2000_shareempl1970)
tab m2000

compress
save ${sourcedata}/rawdata/empljunk00.dta, replace


*** Wages Census 2000 ***
use ${sourcedata}/rawdata/ipums_2000.dta, clear

drop if gq==0 | gq==3 | gq==4 
drop if statefip==2|statefip==15
keep if age>=18 & age<=64
keep if wkswork1>0
drop if school==2
keep if classwkrd>=22 & classwkrd<=28

generate byte imm=(citizen==2 | citizen==3)

summ wkswork1 uhrswork incwage
generate weeks=wkswork1
drop if weeks==0
generate hours=uhrswork
drop if hours==0

keep if incwage>0
replace incwage=incwage*(166.6/166.0)
generate lweekly=log(incwage/weeks)
generate lannual=log(incwage)
generate lwage=log(incwage/(weeks*hours))

generate byte edcode=1*(educd<=50) + 2*(educd>=60 & educd<=64) ///
	+ 3*(educd>=65 & educd<=90) + 4*(educd>=100)

generate exper=age-17 if edcode==1
replace exper=age-19 if edcode==2
replace exper=age-21 if edcode==3
replace exper=age-23 if edcode==4
keep if exper>=1 & exper<=41

generate expcode=1*(exper>=1 & exper<=20) + 2*(exper>=21 & exper<=41)

generate weight=perwt*weeks/52
generate czweight=perwt

** Correct industry 1990 
run dofiles/ind1990aggregation.do

collapse (mean) lweekly (count) sizew=czweight (rawsum) sumweight=weight ///
	[aw=weight], by(ind1990)

generate survey=2000
sort survey ind1990

merge 1:m ind1990 using ${sourcedata}/rawdata/emplsharejunk70.dta, gen(m2000_shareempl1970)
tab m2000

compress
save ${sourcedata}/rawdata/wagesjunk00.dta, replace




*** Empl Census ACS 5yr 2008-2012 ***
use ${sourcedata}/rawdata/ipums_2010.dta, clear

drop if gq==0 | gq==3 | gq==4 
drop if statefip==2|statefip==15
keep if age>=18 & age<=64

generate byte imm=(citizen==2 | citizen==3)

generate byte edcode=1*(educd<=50) + 2*(educd>=60 & educd<=64) ///
	+ 3*(educd>=65 & educd<=90) + 4*(educd>=100)

generate exper=age-17 if edcode==1
replace exper=age-19 if edcode==2
replace exper=age-21 if edcode==3
replace exper=age-23 if edcode==4
keep if exper>=1 & exper<=41

generate weeks=7.4*(wkswork2==1) + 21.3*(wkswork2==2) + 33.1*(wkswork2==3) ///
	+ 42.4*(wkswork2==4) + 48.2*(wkswork2==5) + 51.9*(wkswork2==6) 

generate czweight=perwt

rename statefip state
generate nimmig=imm*czweight*(weeks>0)
generate nnative=(1-imm)*czweight*(weeks>0)

** Correct industry 1990 
run dofiles/ind1990aggregation.do

collapse (sum) nimmig nnative (count) size=czweight, /// 
    by(ind1990)

generate survey=2010
gen x = nimmig+nnative
bys ind1990 survey: egen empl = total(x)
replace empl = log(empl)
rename empl lempl
drop x
sort survey ind1990

merge 1:m ind1990 using ${sourcedata}/rawdata/emplsharejunk70.dta, gen(m2010_shareempl1970)
tab m2010

compress
save ${sourcedata}/rawdata/empljunk10.dta, replace


*** Wages Census ACS 5yr 2008-2012 ***
use ${sourcedata}/rawdata/ipums_2010.dta, clear

drop if gq==0 | gq==3 | gq==4 
drop if statefip==2|statefip==15
keep if age>=18 & age<=64
drop if school==2
keep if wkswork2>0
keep if classwkrd>=22 & classwkrd<=28

generate byte imm=(citizen==2 | citizen==3)

generate byte edcode=1*(educd<=50) + 2*(educd>=60 & educd<=64) ///
	+ 3*(educd>=65 & educd<=90) + 4*(educd>=100)

generate exper=age-17 if edcode==1
replace exper=age-19 if edcode==2
replace exper=age-21 if edcode==3
replace exper=age-23 if edcode==4
keep if exper>=1 & exper<=41

generate expcode=1*(exper>=1 & exper<=20) + 2*(exper>=21 & exper<=41)

generate weeks=7.4*(wkswork2==1) + 21.3*(wkswork2==2) + 33.1*(wkswork2==3) ///
	+ 42.4*(wkswork2==4) + 48.2*(wkswork2==5) + 51.9*(wkswork2==6) 
drop if weeks==0
generate hours=uhrswork
drop if hours==0

keep if incwage>0
replace incwage=incwage*(.726)
generate lweekly=log(incwage/weeks)
generate lannual=log(incwage)
generate lwage=log(incwage/(weeks*hours))

generate weight=perwt*weeks/52
generate czweight=perwt

** Correct industry 1990 
run dofiles/ind1990aggregation.do

collapse (mean) lweekly (count) sizew=czweight (rawsum) sumweight=weight ///
	[aw=weight], by(ind1990)

merge 1:m ind1990 using ${sourcedata}/rawdata/emplsharejunk70.dta, gen(m2010_shareempl1970)
tab m2010

generate survey=2010
sort survey ind1990

compress
save ${sourcedata}/rawdata/wagesjunk10.dta, replace


***************************************************
*** 3. Enclave Bartik share by CZone and decade ***
***************************************************
use Dorn_CZ\cw_ctygrp1970_czone.dta, clear
qui des
local j = `r(N)'+1
set obs `j'
replace ctygrp1970 = 505 if ctygrp1970==.&czone==.&afactor==.
replace czone = 20800 if ctygrp1970==505
replace afactor = 1 if ctygrp1970==505
qui des
local j = `r(N)'+1
set obs `j'
replace ctygrp1970 = 506 if ctygrp1970==.&czone==.&afactor==.
replace czone = 20800 if ctygrp1970==506
replace afactor = 1 if ctygrp1970==506
* Drop Alaska and Hawaii CZone
drop if (czone>=34101&czone<=34115)|(czone>=34701&czone<=34703)|czone==35600
tempfile cw_ctygrp1970_czone_corrected
save `cw_ctygrp1970_czone_corrected'

** Useful dataset that list all CZ
gen one = 1
collapse one, by(czone)
tempfile allczone
save `allczone'

*** Census 1970 (metro fm1) ***
use ${sourcedata}/rawdata/ipums_1970_metrofm1.dta, clear

drop if gq==0 | gq==3 | gq==4 
keep if age>=18 & age<=64

* Rescale perwt due to 2% sample
replace perwt=perwt/2

generate byte imm=(citizen==2 | citizen==3)

generate weeks=8.0*(wkswork2==1) + 20.8*(wkswork2==2) + 33.1*(wkswork2==3) ///
	+ 42.4*(wkswork2==4) + 48.3*(wkswork2==5) + 51.9*(wkswork2==6)
generate hours=8.7*(hrswork2==1) + 20.9*(hrswork2==2) + 31.1*(hrswork2==3) ///
	+ 36.5*(hrswork2==4) + 40*(hrswork2==5) + 45.3*(hrswork2==6) ///
	+ 51.8*(hrswork2==7) + 68.1*(hrswork2==8) 

generate byte edcode=1*(educd<=50) + 2*(educd>=60 & educd<=64) ///
	+ 3*(educd>=65 & educd<=90) + 4*(educd>=100)

generate exper=age-17 if edcode==1
replace exper=age-19 if edcode==2
replace exper=age-21 if edcode==3
replace exper=age-23 if edcode==4
keep if exper>=1 & exper<=41


* Merge with CZ info (obtained by Dorn's website on 1/3/2015,
* "http://www.ddorn.net/data.htm") and create new weights
rename cntygp97 ctygrp1970
joinby ctygrp1970 using `cw_ctygrp1970_czone_corrected'

generate czweight=perwt*afactor

rename statefip state
generate pimmig=imm*czweight
generate pnative=(1-imm)*czweight

tempfile enclavefm1
save `enclavefm1'


*** Census 1970 (metro fm2) ***
use ${sourcedata}/rawdata/ipums_1970_metrofm2.dta, clear

drop if gq==0 | gq==3 | gq==4 
keep if age>=18 & age<=64

* Rescale perwt due to 2% sample
replace perwt=perwt/2

generate byte imm=(bpld>=15000)
replace imm=0 if bpld==90011 | bpld==90021

generate weeks=8.0*(wkswork2==1) + 20.8*(wkswork2==2) + 33.1*(wkswork2==3) ///
	+ 42.4*(wkswork2==4) + 48.3*(wkswork2==5) + 51.9*(wkswork2==6)
generate hours=8.7*(hrswork2==1) + 20.9*(hrswork2==2) + 31.1*(hrswork2==3) ///
	+ 36.5*(hrswork2==4) + 40*(hrswork2==5) + 45.3*(hrswork2==6) ///
	+ 51.8*(hrswork2==7) + 68.1*(hrswork2==8) 


generate byte edcode=1*(educd<=50) + 2*(educd>=60 & educd<=64) ///
	+ 3*(educd>=65 & educd<=90) + 4*(educd>=100)

generate exper=age-17 if edcode==1
replace exper=age-19 if edcode==2
replace exper=age-21 if edcode==3
replace exper=age-23 if edcode==4
keep if exper>=1 & exper<=41

generate expcode=1*(exper>=1 & exper<=20) + 2*(exper>=21 & exper<=41)

* Merge with CZ info (obtained by Dorn's website on 1/3/2015,
* "http://www.ddorn.net/data.htm") and create new weights
rename cntygp97 ctygrp1970
joinby ctygrp1970 using `cw_ctygrp1970_czone_corrected'

generate czweight=perwt*afactor

rename statefip state
generate pimmig=imm*czweight
generate pnative=(1-imm)*czweight

append using `enclavefm1'

** Nationality aggregation & correct for US born abroad
run dofiles/BPLaggregation.do
replace bplgroup = 0 if imm==0&bplgroup>0
replace bplgroup = 1 if imm==1&bplgroup==0

gen mexican = (bplgroup==3)*czweight

** Temporary dataset that list all CZ and nationality
preserve 
gen one = 1
collapse one, by(bplgroup)
drop if bplgroup==0
joinby one using `allczone'
drop one
tempfile allbplgroup
save `allbplgroup'
restore

*** 1970 mexican enclaves ***
preserve
keep czone mexican
collapse (sum) mexican, by(czone)
gen survey = 1970
rename mexican mexicanCZ1970
tempfile mexican70
save `mexican70'
collapse (sum) mexicanCZ1970 (mean) survey
rename mexicanCZ1970 mexicanUS1970 

merge 1:m survey using `mexican70', nogen
save ${sourcedata}/rawdata/mexicanenclavesjunk70.dta, replace
restore


*** 1970 immigrant enclaves ***
preserve 
collapse (sum) pimmig pnative (count) size=czweight, ///
    by(czone bplgroup)
merge 1:1 czone bplgroup using `allbplgroup', gen(m_allbpl)
foreach v of varlist pimmig pnative {
replace `v'=0 if m_allbpl==2
}
drop m_allbpl

gen x = pimmig+pnative
bys czone: egen populationCZ1970 = total(x)
drop x
egen pnativeUS1970=total(pnative)
bys czone: egen pnativeCZ1970=total(pnative)
drop if bplgroup==0
rename pimmig pimmigCZ1970
bys bplgroup: egen pimmigUS1970=total(pimmig)
keep czone bplgroup pimmigCZ1970 pimmigUS1970 populationCZ1970 pnativeCZ1970 pnativeUS1970  
compress
tempfile enclavesjunk1970
save `enclavesjunk1970', replace

collapse (mean) populationCZ1970 pnativeCZ1970, by(czone)
egen populationUS1970=total(populationCZ1970)
egen pnativeUS1970=total(pnativeCZ1970)
drop populationCZ1970 pnativeCZ1970
joinby czone using `enclavesjunk1970'
save ${sourcedata}/rawdata/enclavesjunk70.dta, replace
restore

collapse (sum) pimmig pnative (count) size=czweight, ///
    by(bplgroup)
generate survey=1970
gen x = pimmig+pnative
egen population = total(x)
egen pnativeUS = total(pnative)
drop x
drop if bplgroup==0

keep pimmig population bplgroup survey pnativeUS 

merge 1:m bplgroup using ${sourcedata}/rawdata/enclavesjunk70.dta, gen(m1970)
tab m1970
drop m1970
compress

save ${sourcedata}/rawdata/immigjunk70.dta, replace



*** Census 1980 ***
use ${sourcedata}/rawdata/ipums_1980.dta, clear

drop if gq==0 | gq==3 | gq==4 
keep if age>=18 & age<=64

generate byte imm=(citizen==2 | citizen==3)

summ wkswork1 uhrswork incwage
generate weeks=wkswork1
generate hours=uhrswork

generate byte edcode=1*(educd<=50) + 2*(educd>=60 & educd<=64) ///
	+ 3*(educd>=65 & educd<=90) + 4*(educd>=100)

generate exper=age-17 if edcode==1
replace exper=age-19 if edcode==2
replace exper=age-21 if edcode==3
replace exper=age-23 if edcode==4
keep if exper>=1 & exper<=41

* Merge with CZ info (obtained by Dorn's website on 1/3/2015,
* "http://www.ddorn.net/data.htm") and create new weights
rename cntygp98 ctygrp1980
replace ctygrp1980 = statefip*1000+ctygrp1980
*drop if ctygrp1980==0
joinby ctygrp1980 using Dorn_CZ\cw_ctygrp1980_czone.dta
* Drop Alaska and Hawaii CZone
drop if (czone>=34101&czone<=34115)|(czone>=34701&czone<=34703)|czone==35600

generate czweight=perwt*afactor


rename statefip state
generate pimmig=imm*czweight
generate pnative=(1-imm)*czweight

** Nationality aggregation & correct for US born abroad
run dofiles/BPLaggregation.do
replace bplgroup = 0 if imm==0&bplgroup>0
replace bplgroup = 1 if imm==1&bplgroup==0

gen mexican = (bplgroup==3)*czweight



*** 1980 mexican enclaves ***
preserve
keep czone mexican
collapse (sum) mexican, by(czone)
gen survey = 1980
rename mexican mexicanCZ1980
tempfile mexican80
save `mexican80'
collapse (sum) mexicanCZ1980 (mean) survey
rename mexicanCZ1980 mexicanUS1980 

merge 1:m survey using `mexican80', nogen
save ${sourcedata}/rawdata/mexicanenclavesjunk80.dta, replace
restore


*** 1980 immigrant enclaves ***
preserve 
collapse (sum) pimmig pnative mexican (count) size=czweight, ///
    by(czone bplgroup)
merge 1:1 czone bplgroup using `allbplgroup', gen(m_allbpl)
foreach v of varlist pimmig pnative {
replace `v'=0 if m_allbpl==2
}
drop m_allbpl

gen x = pimmig+pnative
bys czone: egen populationCZ1980 = total(x)
drop x
egen pnativeUS1980=total(pnative)
bys czone: egen pnativeCZ1980=total(pnative)
egen mexicanUS1980=total(mexican)
gen mexicanUS = mexicanUS1980
drop if bplgroup==0
rename pimmig pimmigCZ1980
bys bplgroup: egen pimmigUS1980=total(pimmig)
keep czone bplgroup pimmigCZ1980 pimmigUS1980 populationCZ1980 pnativeCZ1980 pnativeUS1980 mexicanUS1980 mexicanUS
compress
tempfile enclavesjunk1980
save `enclavesjunk1980', replace

collapse (mean) populationCZ1980 pnativeCZ1980, by(czone)
egen populationUS1980=total(populationCZ1980)
egen pnativeUS1980=total(pnativeCZ1980)
drop populationCZ1980 pnativeCZ1980
joinby czone using `enclavesjunk1980'
save ${sourcedata}/rawdata/enclavesjunk80.dta, replace
restore

collapse (sum) pimmig pnative (count) size=czweight, ///
    by(bplgroup)
generate survey=1980
gen x = pimmig+pnative
egen population = total(x)
egen pnativeUS = total(pnative)
drop x
drop if bplgroup==0

keep pimmig population bplgroup survey pnativeUS 


merge 1:m bplgroup using ${sourcedata}/rawdata/enclavesjunk70.dta, gen(m1980)
tab m1980
drop m1980
compress

merge 1:1 czone bplgroup using ${sourcedata}/rawdata/enclavesjunk80.dta, gen(m1980)
tab m1980
drop m1980
compress

merge m:1 czone using ${sourcedata}/rawdata/mexicanenclavesjunk70.dta, gen(mex1980)
tab mex1980
drop mex1980

merge m:1 czone using ${sourcedata}/rawdata/mexicanenclavesjunk80.dta, gen(mex1980)
tab mex1980
drop mex1980

compress

save ${sourcedata}/rawdata/immigjunk80.dta, replace


*** Census 1990 ***
use ${sourcedata}/rawdata/ipums_1990.dta, clear

drop if gq==0 | gq==3 | gq==4 
keep if age>=18 & age<=64

generate byte imm=(citizen==2 | citizen==3)

summ wkswork1 uhrswork incwage
generate weeks=wkswork1
generate hours=uhrswork

generate byte edcode=1*(educd<=50) + 2*(educd>=60 & educd<=64) ///
	+ 3*(educd>=65 & educd<=90) + 4*(educd>=100)

generate exper=age-17 if edcode==1
replace exper=age-19 if edcode==2
replace exper=age-21 if edcode==3
replace exper=age-23 if edcode==4
keep if exper>=1 & exper<=41

generate czweight=perwt

rename statefip state
generate pimmig=imm*czweight
generate pnative=(1-imm)*czweight

** Nationality aggregation & correct for US born abroad
run dofiles/BPLaggregation.do
replace bplgroup = 0 if imm==0&bplgroup>0
replace bplgroup = 1 if imm==1&bplgroup==0

gen mexican = (bplgroup==3)*czweight

collapse (sum) pimmig pnative mexican (count) size=czweight, ///
    by(bplgroup)
generate survey=1990
gen x = pimmig+pnative
egen population = total(x)
egen pnativeUS = total(pnative)
egen mexicanUS=total(mexican)
drop x
drop if bplgroup==0

keep pimmig population bplgroup survey pnativeUS mexicanUS

merge 1:m bplgroup using ${sourcedata}/rawdata/enclavesjunk70.dta, gen(m1990)
tab m1990
drop m1990
compress

merge 1:1 czone bplgroup using ${sourcedata}/rawdata/enclavesjunk80.dta, gen(m1990)
tab m1990
drop m1990

merge m:1 czone using ${sourcedata}/rawdata/mexicanenclavesjunk70.dta, gen(mex1980)
tab mex1980
drop mex1980

merge m:1 czone using ${sourcedata}/rawdata/mexicanenclavesjunk80.dta, gen(mex1980)
tab mex1980
drop mex1980

save ${sourcedata}/rawdata/immigjunk90.dta, replace



*** Census 2000 ***
use ${sourcedata}/rawdata/ipums_2000.dta, clear

drop if gq==0 | gq==3 | gq==4 
keep if age>=18 & age<=64

generate byte imm=(citizen==2 | citizen==3)

generate byte edcode=1*(educd<=50) + 2*(educd>=60 & educd<=64) ///
	+ 3*(educd>=65 & educd<=90) + 4*(educd>=100)

generate exper=age-17 if edcode==1
replace exper=age-19 if edcode==2
replace exper=age-21 if edcode==3
replace exper=age-23 if edcode==4
keep if exper>=1 & exper<=41

generate weeks=wkswork1
generate hours=uhrswork

generate czweight=perwt

rename statefip state
generate pimmig=imm*czweight
generate pnative=(1-imm)*czweight

** Nationality aggregation & correct for US born abroad
run dofiles/BPLaggregation.do
replace bplgroup = 0 if imm==0&bplgroup>0
replace bplgroup = 1 if imm==1&bplgroup==0

gen mexican = (bplgroup==3)*czweight

collapse (sum) pimmig pnative mexican (count) size=czweight, ///
    by(bplgroup)
generate survey=2000
gen x = pimmig+pnative
egen population = total(x)
drop x
egen pnativeUS = total(pnative)
egen mexicanUS=total(mexican)
drop if bplgroup==0

keep pimmig population bplgroup survey pnativeUS mexicanUS

merge 1:m bplgroup using ${sourcedata}/rawdata/enclavesjunk70.dta, gen(m2000)
tab m2000
drop m2000
compress

merge 1:1 czone bplgroup using ${sourcedata}/rawdata/enclavesjunk80.dta, gen(m2000)
tab m2000
drop m2000

merge m:1 czone using ${sourcedata}/rawdata/mexicanenclavesjunk70.dta, gen(mex1980)
tab mex1980
drop mex1980

merge m:1 czone using ${sourcedata}/rawdata/mexicanenclavesjunk80.dta, gen(mex1980)
tab mex1980
drop mex1980

save ${sourcedata}/rawdata/immigjunk00.dta, replace



*** Census ACS 5yr 2008-2012 ***
use ${sourcedata}/rawdata/ipums_2010.dta, clear

drop if gq==0 | gq==3 | gq==4 
keep if age>=18 & age<=64

generate byte imm=(citizen==2 | citizen==3)

generate byte edcode=1*(educd<=50) + 2*(educd>=60 & educd<=64) ///
	+ 3*(educd>=65 & educd<=90) + 4*(educd>=100)

generate exper=age-17 if edcode==1
replace exper=age-19 if edcode==2
replace exper=age-21 if edcode==3
replace exper=age-23 if edcode==4
keep if exper>=1 & exper<=41

generate weeks=7.4*(wkswork2==1) + 21.3*(wkswork2==2) + 33.1*(wkswork2==3) ///
	+ 42.4*(wkswork2==4) + 48.2*(wkswork2==5) + 51.9*(wkswork2==6) 
generate hours=uhrswork

generate czweight=perwt

rename statefip state
generate pimmig=imm*czweight
generate pnative=(1-imm)*czweight

** Nationality aggregation & correct for US born abroad
run dofiles/BPLaggregation.do
replace bplgroup = 0 if imm==0&bplgroup>0
replace bplgroup = 1 if imm==1&bplgroup==0

gen mexican = (bplgroup==3)*czweight

collapse (sum) pimmig pnative mexican (count) size=czweight, ///
    by(bplgroup)
generate survey=2010
gen x = pimmig+pnative
egen population = total(x)
drop x
egen pnativeUS = total(pnative)
egen mexicanUS=total(mexican)
drop if bplgroup==0

keep pimmig population bplgroup survey pnativeUS mexicanUS

merge 1:m bplgroup using ${sourcedata}/rawdata/enclavesjunk70.dta, gen(m2010)
tab m2010
drop m2010

merge 1:1 czone bplgroup using ${sourcedata}/rawdata/enclavesjunk80.dta, gen(m2010)
tab m2010
drop m2010

merge m:1 czone using ${sourcedata}/rawdata/mexicanenclavesjunk70.dta, gen(mex1980)
tab mex1980
drop mex1980

merge m:1 czone using ${sourcedata}/rawdata/mexicanenclavesjunk80.dta, gen(mex1980)
tab mex1980
drop mex1980

compress

save ${sourcedata}/rawdata/immigjunk10.dta, replace




******************************************************************************
*** 4. Sector Wage & Emplotyment Bartik, Enclave Bartik: put data together ***
******************************************************************************
use ${sourcedata}/rawdata/wagesjunk70.dta, clear
append using ${sourcedata}/rawdata/wagesjunk80.dta
append using ${sourcedata}/rawdata/wagesjunk90.dta
append using ${sourcedata}/rawdata/wagesjunk00.dta
append using ${sourcedata}/rawdata/wagesjunk10.dta

sort czone ind1990 survey
by czone ind1990: gen dlweekly = lweekly - lweekly[_n-1] if _n>1
gen dbartikwage = dlweekly*shempl1970
collapse (sum) dbartikwage, by(czone survey)

tempfile bartikwage
save `bartikwage', replace

use ${sourcedata}/rawdata/empljunk70.dta, clear
append using ${sourcedata}/rawdata/empljunk80.dta
append using ${sourcedata}/rawdata/empljunk90.dta
append using ${sourcedata}/rawdata/empljunk00.dta
append using ${sourcedata}/rawdata/empljunk10.dta

sort czone ind1990 survey
by czone ind1990: gen dlempl = lempl - lempl[_n-1] if _n>1
gen dbartikempl = dlempl*shempl1970

collapse (sum) dbartikempl, by(czone survey)

compress 
tempfile bartikempl
save `bartikempl', replace

use ${sourcedata}/rawdata/immigjunk70.dta, clear
append using ${sourcedata}/rawdata/immigjunk80.dta
append using ${sourcedata}/rawdata/immigjunk90.dta
append using ${sourcedata}/rawdata/immigjunk00.dta
append using ${sourcedata}/rawdata/immigjunk10.dta

bys czone bplgroup survey: gen foreignhat_b1970 = (pimmigCZ1970)*(pimmig/pimmigUS1970)
bys czone bplgroup survey: gen nativeshat_b1970 = pnativeCZ1970*(pnativeUS/pnativeUS1970)
bys czone bplgroup survey: gen foreignhat_b1980 = (pimmigCZ1980)*(pimmig/pimmigUS1980)
bys czone bplgroup survey: gen nativeshat_b1980 = pnativeCZ1980*(pnativeUS/pnativeUS1980)
bys czone bplgroup survey: gen enclave_b1970 = (pimmigCZ1970/populationCZ1970)*(pimmig/pimmigUS1970)*(population/populationUS1970)
bys czone bplgroup survey: gen enclave_b1980 = (pimmigCZ1980/populationCZ1980)*(pimmig/pimmigUS1980)*(population/populationUS1980)


bys czone survey: gen mexicanhat_b1970 = (mexicanCZ1970)*(mexicanUS/mexicanUS1970)
bys czone survey: gen mexicanhat_b1980 = (mexicanCZ1980)*(mexicanUS/mexicanUS1980)

save C:\Users\Tano\Dropbox\temp.dta, replace

collapse (mean) nativeshat* mexicanhat* (sum) enclave* foreignhat*, by(czone survey)
bys czone: gen time=_n
xtset czone time

foreach v in mexicanhat_b1980 foreignhat_b1980 enclave_b1980 nativeshat_b1980 {
replace `v' = . if survey==1970
}

gen denclave_0_b1970 = d.enclave_b1970
gen denclave_0_b1980 = d.enclave_b1980

merge 1:1 czone survey using `bartikwage', gen(m_wage)
tab m_w
merge 1:1 czone survey using `bartikempl', gen(m_empl)
tab m_e

drop m_* enclave* time
xtset, clear


compress
save data/bartikwageemplenclaves.dta, replace

log close

*** Clean folder ***
cd ${sourcedata}/rawdata
shell erase immigjunk?0.dta
shell erase empljunk?0.dta
shell erase wagesjunk?0.dta
shell erase junk70fm1.dta
shell erase emplsharejunk?0.dta
shell erase enclavesjunk?0.dta

