set more off
cap log close

cd C:\Users\Tano\Dropbox\Giovanni_MigrationConference2015

log using logfiles\dataset_aggregated_region_census19702010.txt, text replace

disp "DateTime: $S_DATE $S_TIME"

/* *******************************************************************
 Merge count and wages Borjas' region dataset to obtain a region-aggregated 
 dataset with count of immigrants, wages natives and population. For each 
 region in 1970-2010.
 
 Created on 1/9/2015 by Gaetano Basso (gbasso@ucdavis.edu)
******************************************************************* */

unzipfile wage_empl_codes_Borjas.zip

use wage_region_mf.dta, clear

drop if imm==1
drop imm

merge 1:1 edcode expcode region survey using count_region_mf.dta, nogen
drop if survey==1960

preserve
keep if edcode==1|edcode==2
collapse (mean) lweekly_lskill=lweekly lannual_lskill=lannual ///
	lwage_lskill=lwage [aw=nnative] , by(region survey)
tempfile lowskill
save `lowskill'
restore
preserve
keep if edcode==3|edcode==4
collapse (mean) lweekly_hskill=lweekly lannual_hskill=lannual ///
	lwage_hskill=lwage [aw=nnative], by(region survey)
tempfile highskill
save `highskill'
restore

collapse (mean) lweekly lannual lwage ///
	(rawsum) pimmig pnative nnative sizecounts=size ///
	[aw=nnative], by(region survey)

merge 1:1 region survey using `lowskill', nogen
merge 1:1 region survey using `highskill', nogen

** generate immigrant share & population
gen population = pimmig+pnative

gen population_70=population if survey==1970
replace population_70=population_70[_n-1] if survey>survey[_n-1]
gen x=population if survey==2010
bys region: egen population_10=max(x)
drop x

gen shareimmig = pimmig/(pimmig+pnative)
gen shareimmig_70=shareimmig if survey==1970
replace shareimmig_70=shareimmig_70[_n-1] if survey>survey[_n-1]
gen x=shareimmig if survey==2010
bys region: egen shareimmig_10=max(x)
drop x

gen pimmig_70=pimmig if survey==1970
replace pimmig_70=pimmig_70[_n-1] if survey>survey[_n-1]
gen x=pimmig if survey==2010
bys region: egen pimmig_10=max(x)
drop x

gen nnative_70=nnative if survey==1970
replace nnative_70=nnative_70[_n-1] if survey>survey[_n-1]
gen x=nnative if survey==2010
bys region: egen nnative_10=max(x)
drop x

** generate the variables in c=standardized changes (Giovanni) **
gen d_immi_std=(pimmig-pimmig[_n-1])/(pimmig[_n-1]+pnative[_n-1]) if survey>survey[_n-1]
gen d20101970_immi_std=(pimmig_10-pimmig_70)/(population_70) 

** change in native employment/population (Giovanni) **
gen dnnative=(nnative-nnative[_n-1])/(pimmig[_n-1]+pnative[_n-1]) if survey>survey[_n-1]
gen d20101970nnative=(nnative_10-nnative_70)/(population_70) 

gen dpopulation=(population-population[_n-1])/(population[_n-1]) if survey>survey[_n-1]
gen d20101970population=(population_10-population_70)/(population_70)


* Generate time variable, first differences, baseline population
gen decade = 1 if survey==1970
replace decade = 2 if survey==1980
replace decade = 3 if survey==1990
replace decade = 4 if survey==2000
replace decade = 5 if survey==2010

label define decadename 2 "1970-1980" 3 "1980-1990" 4 "1990-2000" 5 "2000-2010"
label values decade decadename

xtset region decade
foreach v in lweekly lannual lwage ///
	lweekly_lskill lannual_lskill lwage_lskill ///
	lweekly_hskill lannual_hskill lwage_hskill shareimmig {
gen d`v'=d.`v'
gen x = `v'*(survey==1970) 
gen y = `v'*(survey==2010)
bys region: egen `v'1970=max(x)
bys region: egen `v'2010=max(y)
bys region: gen d20101970`v'= `v'2010-`v'1970
drop x y `v'2010 `v'1970
}

** Label Variables 
la var lweekly "Weekly Wages"
la var lannual "Annual Wages"
la var lwage "Hourly Wages"
la var lweekly_lsk "Weekly Wages (Low Skill)"
la var lannual_lsk "Annual Wages (Low Skill)"
la var lwage_lsk "Hourly Wages (Low Skill)"
la var lweekly_hsk "Weekly Wages (High Skill)"
la var lannual_hsk "Annual Wages (High Skill)"
la var lwage_hsk "Hourly Wages (High Skill)"
la var pimmig "Immigrants Population"
la var pnative "Natives Population"
la var nnative "Natives Employment"
la var population "Population"
la var shareimmig "Immigrant Share"
la var d_immi_std "Immigrant Change (Std'd)"
la var dnnative "Native Employment (Std'd)" 
la var dpopulation "Population (Std'd)" 
xtset

cap drop _*
compress
saveold data/aggregated_region.dta, replace

/*
*** Check manually that the aggregated dataset is correct ***
use wage_region_mf.dta, clear

drop if imm==1
drop imm

merge 1:1 edcode expcode region survey using count_region_mf.dta, nogen
drop if survey==1960

bys region survey: egen cznnative = total(nnative)
bys region survey: egen czpimmig = total(pimm)
bys region survey: egen czpnative = total(pnative)
foreach v of varlist lweekly lannual lwage {
bys region survey: egen cz`v'=total(`v'*nnative)
bys region survey: replace cz`v'=cz`v'/cznnative
}
sort region survey
keep cz* survey 
foreach v in lweekly lannual lwage pimmig pnative nnative {
rename cz`v' `v'
}

duplicates drop

set more on
cf lweekly lannual lwage using data/aggregated_region.dta, all verbose
*/

log close

*** Clean folder ***
shell erase *.dta
shell erase *.do


